@@ -12,9 +12,6 @@
 
 #include "ctvariable.h"
 
-#include "taskEditorDialog.h"
-#include "variableEditorDialog.h"
-
 VariableWidget::VariableWidget(VariablesWidget *_variablesWidget, CTVariable *_ctVariable)
     : QTreeWidgetItem(_variablesWidget->treeWidget())
 {
